import React, { useState } from 'react';
import { Button } from '@/components/ui/button';
import { ArrowRight, Shield, CheckCircle } from 'lucide-react';
import { motion } from 'framer-motion';
import {
  Dialog,
  DialogContent,
  DialogHeader,
  DialogTitle,
  DialogDescription,
} from '@/components/ui/dialog';
import { BmwPpfImage, BmwRedPpfImage, BmwRedSedan, BmwRedPartial, BmwStandardZone, BmwBumperProtection, BmwInteriorProtection, BmwHeadlightsProtection } from '../assets';

type PackageType = {
  id: string;
  title: string;
  description: string;
  features: string[];
  fullDescription: string;
  benefits: string[];
  image: string;
};

const packageTypesEt: PackageType[] = [
  {
    id: 'full',
    title: 'Täielik kiletamine',
    description: 'Maksimaalne kaitse kogu auto kerele. Pakume täielikku kaitset kõikidele välistele pindadele.',
    features: [
      'Kogu auto värvkatte kaitse',
      'Esikaitseraud, kapott, tiivad, uksed',
      'Tagakaitseraud, pagasiluuk, küljepaneelid',
      'Peeglid, tuled, iluvõre',
      'Lävepakud ja muud kriitilised alad'
    ],
    fullDescription: 'Täielik kiletamine annab teie autole maksimaalse kaitse. See pakett hõlmab kogu auto kerepinna kaitsmist PPF bronekile abil, mis kaitseb teie sõidukit kivitäkete, kriimustuste, putukate, teesoola, UV-kiirguse ja teiste väliste tegurite eest. Tänu iseparanevale tehnoloogiale säilib auto esialgne värvkate ideaalses seisukorras aastaid, säilitades selle välimuse ja taastades sõiduki täismüügiväärtuse müümisel.',
    benefits: [
      'Kõige põhjalikum kaitse',
      'Säilitab auto esialgse välimuse',
      'Pikendab autovärvi eluiga',
      'Kergendab auto puhastamist',
      'Kõrgem edasimüügiväärtus'
    ],
    image: BmwRedSedan
  },
  {
    id: 'partial',
    title: 'Osaline kiletamine',
    description: 'Meie osaline kiletamine kaitseb autot kõige kriitilisemates kohtades, tagades optimaalse kaitse põhialadele.',
    features: [
      'Esikaitseraud täielikult',
      'Kapott (täielik või osaline)',
      'Esimesed rattakoobaste ümbrused',
      'Autotuled ja peeglid',
      'Küljepeeglid'
    ],
    fullDescription: 'Osaline kiletamine kaitseb teie auto kõige haavatavamaid osi. See pakett on ideaalne lahendus neile, kes soovivad kaitset just kõige kriitilisemates kohtades, mis on teel liikudes kivitägetele ja muudele kahjustustele kõige rohkem avatud. Kiletame esikaitseraua, kapoti, esimesed tiivad, peeglid ja esituled, mis pakub tõhusat kaitset, hoides teie auto esiosa värskena ja ilma kahjustusteta.',
    benefits: [
      'Optimaalne hinna ja kaitse suhe',
      'Fokuseeritud kriitiliste alade kaitsele',
      'Väiksem paigaldusaeg (4-8 tundi)',
      'Oluline kaitse igapäevaseks sõitmiseks',
      'Lihtne hooldus'
    ],
    image: BmwRedPartial
  },
  {
    id: 'risk',
    title: 'Riskitsoonid "Standard"',
    description: 'Kaitsekile paigaldamine auto kõige haavatavamatele pindadele, mis puutuvad esimesena kokku teel lenduvate kividega.',
    features: [
      'Esikaitseraua keskel osa',
      'Kapoti eesmine osa (30%)',
      'Peeglid täielikult',
      'Esituled täielikult',
      'Esimesed poritiivad osaliselt'
    ],
    fullDescription: 'Riskitsoonide "Standard" pakett keskendub teie auto kõige haavatavamatele osadele, mis on igapäevase sõidu käigus kivitägetele ja kahjustustele kõige rohkem avatud. See pakett sisaldab esikaitseraua keskmist osa, kapoti eesmist osa, peegleid ja esitulesid, pakkudes kaitset just seal, kus seda kõige rohkem vaja on. See on kuluefektiivne lahendus, mis pakub siiski olulist kaitset teie auto välimuse säilitamiseks.',
    benefits: [
      'Kuluefektiivne lahendus põhikaitseks',
      'Lühike paigaldusaeg (2-4 tundi)',
      'Kaitseb kõige haavatavamaid alasid',
      'Pikendab oluliselt auto värvkatte eluiga',
      'Sobib ka vanemale autole'
    ],
    image: BmwStandardZone
  },
  {
    id: 'premium',
    title: 'Riskitsoonid "Premium"',
    description: 'Laiendatud kaitse kõigil kriitilistel aladel, mis lisab standardsele kaitsele täiendavaid piirkondi paremaks kaitseks.',
    features: [
      'Kõik Standard paketi alad',
      'Kapott täielikult',
      'Lävepakud',
      'Pagasiluugi ülemine osa',
      'Tagumised rattakoopad osaliselt'
    ],
    fullDescription: 'Riskitsoonide "Premium" pakett on laiendatud lahendus, mis kaitseb lisaks standardsetele riskitsoonidele täiendavaid kriitilisi alasid. Lisaks esikaitserauale, kapotile, peeglitele ja esituledele kiletame lävepakud, pagasiluugi ja osa tagumistest rattakoobaste ümbrusest. See pakett sobib sõidukitele, mida kasutatakse aktiivselt ja mis vajavad tugevamat kaitset kui standardne riskitsoonide pakett, kuid ei vaja täielikku kiletamist.',
    benefits: [
      'Laiem kaitse kui Standard paketis',
      'Pikaajaline kaitse lisaaladele',
      'Keskmise pikkusega paigaldusaeg (4-6 tundi)',
      'Täiendav kaitse ka tagaosale',
      'Ideaalne aktiivselt kasutatavale autole'
    ],
    image: BmwRedPpfImage
  },
  {
    id: 'bumpers',
    title: 'Põrkeraudade kaitsekile',
    description: 'Spetsiaalne kaitsekile auto põrkeraudadele, mis kaitseb nii esi- kui tagaosa kõige sagedamini kahjustatud piirkondi.',
    features: [
      'Esikaitseraud täielikult',
      'Tagakaitseraud täielikult',
      'Põrkeraudade servad ja nurgad',
      'Laadimisala kaitse',
      'Vastupidav kaitse kriimustuste eest'
    ],
    fullDescription: 'Põrkeraudade kaitsekile pakett on spetsiaalselt loodud kaitsma teie auto esi- ja tagakaitseraudu, mis on kõige altimad kriimustustele, kivitäketele ja igapäevastele kahjustustele. See pakett pakub täielikku kaitset mõlemale põrkerauale, tagades nende originaalse välimuse säilimise. Põrkeraudade PPF kile on vastupidav lahendus, mis kaitseb autot parkimiskahjustuste, kivisöe ja teeprahi eest. See on eriti kasulik linnas sõitjatele ja neile, kes pargib tihedalt asustatud kohtades.',
    benefits: [
      'Sihipärane kaitse kõige kahjustatavamatele aladele',
      'Väldib kalleid põrkeraudade remondi- ja värvimistöid',
      'Kaitseb nii esi- kui tagakaitseraudu',
      'Säilitab auto puhta ja kriimustusteta välimuse',
      'Iseparanev tehnoloogia väiksemate kriimustuste vastu'
    ],
    image: BmwBumperProtection
  },
  {
    id: 'headlights_protection',
    title: 'Esitulede kaitsekile',
    description: 'Spetsiaalne kaitsekile auto esituledele, mis tagab tulede läbipaistvuse ja kaitseb neid kildude ning kahjustuste eest.',
    features: [
      'Mõlemad esituled täielikult',
      'Läbipaistev spetsiaalne kile',
      'Fikseeritud hind kõikidele automudelitele',
      'Lühike paigaldusaeg (1-2 tundi)',
      'Kile ei mõjuta valguse läbilaskvust'
    ],
    fullDescription: 'Meie esitulede kaitsekile pakett pakub spetsiaalset kaitset teie auto tuledele, mis on tihti ühed kallimad osad autol, kui neid tuleb asendada. Läbipaistev kile ei mõjuta valguse läbilaskvust, kuid kaitseb tulesid kivitäkete, kriimustuste ja UV-kiirguse eest, hoides need selged ja kahjustamata. See on soodne ja kiire paigaldusega teenus, mida pakume kõikidele automudelitele fikseeritud hinnaga 90€.',
    benefits: [
      'Kaitseb kalleid esitulesid kahjustuste eest',
      'Säilitab tulede originaalne välimus',
      'Pikendab tulede eluiga',
      'Kiire paigaldus (1-2 tundi)',
      'Soodne hind (90€) kõikidele automudelitele'
    ],
    image: BmwHeadlightsProtection
  }
];

// Russian package types
const packageTypesRu: PackageType[] = [
  {
    id: 'full',
    title: 'Полная оклейка кузова',
    description: 'Максимальная защита всего кузова автомобиля. Мы предлагаем полную защиту всех внешних поверхностей.',
    features: [
      'Защита всей лакокрасочной поверхности',
      'Передний бампер, капот, крылья, двери',
      'Задний бампер, багажник, боковые панели',
      'Зеркала, фары, решетка радиатора',
      'Пороги и другие критические зоны'
    ],
    fullDescription: 'Полная оклейка кузова обеспечивает максимальную защиту вашего автомобиля. Этот пакет включает защиту всей поверхности кузова автомобиля с помощью антигравийной пленки PPF, которая защищает ваш автомобиль от сколов, царапин, насекомых, дорожной соли, УФ-излучения и других внешних факторов. Благодаря самовосстанавливающейся технологии оригинальное лакокрасочное покрытие автомобиля сохраняется в идеальном состоянии в течение многих лет, сохраняя его внешний вид и восстанавливая полную рыночную стоимость автомобиля при продаже.',
    benefits: [
      'Самая всесторонняя защита',
      'Сохраняет первоначальный вид автомобиля',
      'Продлевает срок службы краски',
      'Облегчает чистку автомобиля',
      'Повышенная стоимость при перепродаже'
    ],
    image: BmwRedSedan
  },
  {
    id: 'partial',
    title: 'Частичная оклейка кузова',
    description: 'Наша частичная оклейка защищает автомобиль в наиболее критических местах, обеспечивая оптимальную защиту основных зон.',
    features: [
      'Полностью передний бампер',
      'Капот (полностью или частично)',
      'Области вокруг передних колесных арок',
      'Фары и зеркала автомобиля',
      'Боковые зеркала'
    ],
    fullDescription: 'Частичная оклейка защищает наиболее уязвимые части вашего автомобиля. Этот пакет является идеальным решением для тех, кто хочет защиту именно в самых критических местах, которые наиболее подвержены сколам и другим повреждениям при движении по дороге. Мы оклеиваем передний бампер, капот, передние крылья, зеркала и фары, что обеспечивает эффективную защиту, сохраняя переднюю часть вашего автомобиля свежей и без повреждений.',
    benefits: [
      'Оптимальное соотношение цены и защиты',
      'Направлена на защиту критических зон',
      'Меньшее время установки (4-8 часов)',
      'Значительная защита для повседневного вождения',
      'Простое обслуживание'
    ],
    image: BmwRedPartial
  },
  {
    id: 'risk',
    title: 'Зоны риска "Стандарт"',
    description: 'Установка защитной пленки на наиболее уязвимые поверхности автомобиля, которые первыми соприкасаются с летящими камнями на дороге.',
    features: [
      'Центральная часть переднего бампера',
      'Передняя часть капота (30%)',
      'Полностью зеркала',
      'Полностью фары',
      'Частично передние крылья'
    ],
    fullDescription: 'Пакет "Зоны риска Стандарт" концентрируется на наиболее уязвимых частях вашего автомобиля, которые наиболее подвержены сколам и повреждениям во время повседневного вождения. Этот пакет включает среднюю часть переднего бампера, переднюю часть капота, зеркала и фары, обеспечивая защиту там, где она больше всего необходима. Это экономичное решение, которое все же обеспечивает значительную защиту для сохранения внешнего вида вашего автомобиля.',
    benefits: [
      'Экономичное решение для базовой защиты',
      'Короткое время установки (2-4 часа)',
      'Защищает самые уязвимые зоны',
      'Значительно продлевает срок службы краски',
      'Подходит и для старых автомобилей'
    ],
    image: BmwStandardZone
  },
  {
    id: 'premium',
    title: 'Зоны риска "Премиум"',
    description: 'Расширенная защита всех критических зон, добавляющая дополнительные области к стандартной защите для лучшей сохранности.',
    features: [
      'Все зоны пакета "Стандарт"',
      'Капот полностью',
      'Пороги',
      'Верхняя часть багажника',
      'Частично задние колесные арки'
    ],
    fullDescription: 'Пакет "Зоны риска Премиум" - это расширенное решение, которое защищает дополнительные критические зоны помимо стандартных зон риска. В дополнение к переднему бамперу, капоту, зеркалам и фарам мы оклеиваем пороги, багажник и часть области вокруг задних колесных арок. Этот пакет подходит для автомобилей, которые используются активно и требуют более сильной защиты, чем стандартный пакет зон риска, но не требуют полной оклейки.',
    benefits: [
      'Более широкая защита, чем в пакете "Стандарт"',
      'Долгосрочная защита дополнительных зон',
      'Среднее время установки (4-6 часов)',
      'Дополнительная защита задней части',
      'Идеально для активно используемого автомобиля'
    ],
    image: BmwRedPpfImage
  },
  {
    id: 'bumpers',
    title: 'Защита бамперов пленкой',
    description: 'Специальная защитная пленка для бамперов автомобиля, защищающая наиболее часто повреждаемые зоны передней и задней части.',
    features: [
      'Полностью передний бампер',
      'Полностью задний бампер',
      'Края и углы бамперов',
      'Защита зоны погрузки',
      'Прочная защита от царапин'
    ],
    fullDescription: 'Пакет защиты бамперов специально разработан для защиты переднего и заднего бамперов вашего автомобиля, которые наиболее подвержены царапинам, сколам и повседневным повреждениям. Этот пакет обеспечивает полную защиту обоих бамперов, гарантируя сохранение их первоначального вида. Антигравийная пленка для бамперов - это долговечное решение, которое защищает автомобиль от повреждений при парковке, гравия и дорожного мусора. Это особенно полезно для городских водителей и тех, кто паркуется в густонаселенных местах.',
    benefits: [
      'Целенаправленная защита наиболее повреждаемых зон',
      'Избегает дорогостоящего ремонта и покраски бамперов',
      'Защищает как передний, так и задний бамперы',
      'Сохраняет чистый вид автомобиля без царапин',
      'Самовосстанавливающаяся технология против мелких царапин'
    ],
    image: BmwBumperProtection
  },
  {
    id: 'headlights_protection',
    title: 'Защита фар пленкой',
    description: 'Специальная защитная пленка для фар автомобиля, обеспечивающая прозрачность фар и защищающая их от осколков и повреждений.',
    features: [
      'Обе фары полностью',
      'Прозрачная специальная пленка',
      'Фиксированная цена для всех моделей авто',
      'Короткое время установки (1-2 часа)',
      'Пленка не влияет на светопропускание'
    ],
    fullDescription: 'Наш пакет защиты фар предлагает специальную защиту для фар вашего автомобиля, которые часто являются одними из самых дорогих деталей автомобиля при необходимости замены. Прозрачная пленка не влияет на светопропускание, но защищает фары от сколов, царапин и УФ-излучения, сохраняя их ясными и неповрежденными. Это недорогая услуга с быстрой установкой, которую мы предлагаем для всех моделей автомобилей по фиксированной цене 90€.',
    benefits: [
      'Защищает дорогие фары от повреждений',
      'Сохраняет оригинальный вид фар',
      'Продлевает срок службы фар',
      'Быстрая установка (1-2 часа)',
      'Доступная цена (90€) для всех моделей автомобилей'
    ],
    image: BmwHeadlightsProtection
  }
];

const container = {
  hidden: { opacity: 0 },
  show: {
    opacity: 1,
    transition: {
      staggerChildren: 0.1
    }
  }
};

const item = {
  hidden: { opacity: 0, y: 20 },
  show: { opacity: 1, y: 0 }
};

const Services: React.FC = () => {
  const isRussian = document.documentElement.lang === 'ru';
  const currentPackageTypes = isRussian ? packageTypesRu : packageTypesEt;
  
  const [selectedPackage, setSelectedPackage] = useState<PackageType | null>(null);
  const [dialogOpen, setDialogOpen] = useState(false);

  const handlePackageClick = (packageType: PackageType) => {
    setSelectedPackage(packageType);
    setDialogOpen(true);
  };

  return (
    <section id="teenused" className="py-16 bg-white">
      <div className="container mx-auto px-4">
        <div className="text-center mb-12">
          <h2 className="text-3xl font-bold mb-4">
            {document.documentElement.lang === 'ru' 
              ? "Комплексные пакеты антигравийной защиты PPF" 
              : "Kiletamise paketid"}
          </h2>
          <p className="text-gray-600 max-w-3xl mx-auto">
            {document.documentElement.lang === 'ru' 
              ? "Выберите оптимальный вариант защиты кузова с помощью высококачественной антигравийной пленки PPF в соответствии с вашими потребностями и бюджетом. Стоимость наших пакетов зависит от класса автомобиля, кроме защиты фар, которая имеет фиксированную цену." 
              : "Vali endale sobiv kiletamise pakett vastavalt kaitse vajadusele ja eelarvele. Meie pakettide hinnad sõltuvad auto klassist, välja arvatud esitulede kaitsekile, millel on fikseeritud hind."}
          </p>
        </div>
        
        <motion.div
          variants={container}
          initial="hidden"
          whileInView="show"
          viewport={{ once: true, amount: 0.2 }}
          className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-2 gap-8"
        >
          {currentPackageTypes.map((packageType: PackageType) => (
            <motion.div
              key={packageType.id}
              variants={item}
              className="bg-accent rounded-lg overflow-hidden shadow-sm hover:shadow-md transition-shadow"
            >
              <div className="relative h-52 overflow-hidden">
                {/* Simplified image rendering without WebP/AVIF since they're not yet generated */}
                <img 
                  src={packageType.image} 
                  alt={packageType.title} 
                  className="w-full h-full object-cover transition-transform hover:scale-105 duration-500"
                  loading="lazy"
                  decoding="async"
                  width="600"
                  height="300"
                />
              </div>
              <div className="p-6">
                <h3 className="text-xl font-medium mb-2 flex items-center">
                  <Shield className="mr-2 h-5 w-5 text-primary" />
                  {packageType.title}
                </h3>
                <p className="text-gray-600 mb-4">{packageType.description}</p>
                
                <div className="mb-4">
                  <h4 className="font-medium mb-2">
                    {document.documentElement.lang === 'ru' 
                      ? "Комплект включает:" 
                      : "Pakett sisaldab:"}
                  </h4>
                  <ul className="space-y-1">
                    {packageType.features.slice(0, 3).map((feature: string, index: number) => (
                      <li key={index} className="flex items-start">
                        <CheckCircle className="mr-2 h-4 w-4 text-primary mt-1 flex-shrink-0" />
                        <span className="text-sm text-gray-600">{feature}</span>
                      </li>
                    ))}
                  </ul>
                </div>
                
                <Button 
                  variant="link" 
                  className="text-primary p-0 font-medium hover:underline"
                  onClick={() => handlePackageClick(packageType)}
                >
                  {document.documentElement.lang === 'ru' 
                    ? "Подробнее" 
                    : "Vaata täpsemalt"} <ArrowRight className="ml-1 h-4 w-4" />
                </Button>
              </div>
            </motion.div>
          ))}
        </motion.div>
        
        {/* Interior PPF Protection - Custom Request Only */}
        <motion.div
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5, delay: 0.3 }}
          className="mt-16 bg-accent rounded-lg overflow-hidden shadow-md"
        >
          <div className="grid grid-cols-1 md:grid-cols-2">
            <div className="order-2 md:order-1 p-8">
              <h3 className="text-2xl font-bold mb-4 flex items-center">
                <Shield className="mr-2 h-6 w-6 text-primary" />
                {document.documentElement.lang === 'ru' 
                  ? "Защита интерьера автомобиля пленкой PPF" 
                  : "Auto sisemuse PPF kaitsekile"}
              </h3>
              <p className="text-gray-600 mb-6">
                {document.documentElement.lang === 'ru' 
                  ? "Мы также предлагаем защиту интерьера автомобиля специальной защитной пленкой PPF. Данная услуга доступна только по индивидуальному запросу, так как каждый салон имеет уникальные особенности и потребности." 
                  : "Pakume ka auto sisemuse (interjööri) kaitsmist spetsiaalse PPF kaitsekile abil. See teenus on saadaval ainult individuaalse hinnapakkumise alusel, sest iga auto sisemuse vajadused on unikaalsed."}
              </p>
              <div className="mb-6">
                <h4 className="font-medium mb-2">
                  {document.documentElement.lang === 'ru' 
                    ? "Возможные зоны защиты:" 
                    : "Võimalikud kaitsealad:"}
                </h4>
                <ul className="space-y-2">
                  <li className="flex items-start">
                    <CheckCircle className="mr-2 h-4 w-4 text-primary mt-1 flex-shrink-0" />
                    <span className="text-gray-600">
                      {document.documentElement.lang === 'ru' 
                        ? "Навигационный экран и цифровая приборная панель" 
                        : "Navikatsiooniekraan ja digitaalne näidikupaneel"}
                    </span>
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="mr-2 h-4 w-4 text-primary mt-1 flex-shrink-0" />
                    <span className="text-gray-600">
                      {document.documentElement.lang === 'ru' 
                        ? "Поверхности центральной консоли (глянцевые и подверженные царапинам области)" 
                        : "Keskkonsooli pinnad (läikivad ja kriimustustundlikud alad)"}
                    </span>
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="mr-2 h-4 w-4 text-primary mt-1 flex-shrink-0" />
                    <span className="text-gray-600">
                      {document.documentElement.lang === 'ru' 
                        ? "Защита сидений (защита кожаных сидений)" 
                        : "Istmete kaitse (nahast istmete kaitsmine)"}
                    </span>
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="mr-2 h-4 w-4 text-primary mt-1 flex-shrink-0" />
                    <span className="text-gray-600">
                      {document.documentElement.lang === 'ru' 
                        ? "Дверные ручки и панели" 
                        : "Ukselingid ja -paneelid"}
                    </span>
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="mr-2 h-4 w-4 text-primary mt-1 flex-shrink-0" />
                    <span className="text-gray-600">
                      {document.documentElement.lang === 'ru' 
                        ? "Другое: пороги, багажник и т.д." 
                        : "Muu: lävepakud, pagasiruum, jne"}
                    </span>
                  </li>
                </ul>
              </div>
              <Button
                onClick={() => document.getElementById('kontakt')?.scrollIntoView()}
                className="bg-primary hover:bg-primary/90"
              >
                {document.documentElement.lang === 'ru' 
                  ? "Запросить предложение" 
                  : "Küsi pakkumist"}
              </Button>
            </div>
            <div className="order-1 md:order-2 relative h-full min-h-[300px]">
              {/* Simple image display without WebP/AVIF for now */}
              <img 
                src={BmwInteriorProtection} 
                alt="BMW Interior PPF Protection" 
                className="w-full h-full object-cover"
                loading="lazy"
                decoding="async"
                width="600"
                height="400"
              />
            </div>
          </div>
        </motion.div>
      </div>
      
      <Dialog open={dialogOpen} onOpenChange={setDialogOpen}>
        <DialogContent className="sm:max-w-[600px]">
          {selectedPackage && (
            <>
              <DialogHeader>
                <DialogTitle className="flex items-center">
                  <Shield className="mr-2 h-5 w-5 text-primary" />
                  {selectedPackage.title}
                </DialogTitle>
              </DialogHeader>
              <div className="mt-4">
                {/* Simple image display without WebP/AVIF for now */}
                <img 
                  src={selectedPackage.image} 
                  alt={selectedPackage.title}
                  className="w-full h-64 object-cover rounded-md mb-4"
                  loading="lazy"
                  decoding="async"
                  width="600"
                  height="400"
                />
                <DialogDescription className="text-base mb-4">
                  {selectedPackage.fullDescription}
                </DialogDescription>
                
                <div className="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                  <div>
                    <h4 className="font-medium mb-2">
                      {document.documentElement.lang === 'ru' 
                        ? "Состав комплекта:" 
                        : "Paketi sisud:"}
                    </h4>
                    <ul className="space-y-1">
                      {selectedPackage.features.map((feature: string, index: number) => (
                        <li key={index} className="flex items-start">
                          <CheckCircle className="mr-2 h-4 w-4 text-primary mt-1 flex-shrink-0" />
                          <span className="text-sm text-gray-600">{feature}</span>
                        </li>
                      ))}
                    </ul>
                  </div>
                  
                  <div>
                    <h4 className="font-medium mb-2">
                      {document.documentElement.lang === 'ru' 
                        ? "Преимущества:" 
                        : "Eelised:"}
                    </h4>
                    <ul className="space-y-1">
                      {selectedPackage.benefits.map((benefit: string, index: number) => (
                        <li key={index} className="flex items-start">
                          <CheckCircle className="mr-2 h-4 w-4 text-primary mt-1 flex-shrink-0" />
                          <span className="text-sm text-gray-600">{benefit}</span>
                        </li>
                      ))}
                    </ul>
                  </div>
                </div>
              </div>
              <div className="mt-4">
                <Button
                  onClick={() => document.getElementById('hinnakiri')?.scrollIntoView()}
                  className="w-full bg-primary hover:bg-primary/90"
                >
                  {document.documentElement.lang === 'ru' 
                    ? "Рассчитать стоимость" 
                    : "Arvuta hind"}
                </Button>
              </div>
            </>
          )}
        </DialogContent>
      </Dialog>
    </section>
  );
};

export default Services;
